# Latias::Influxdb

Ruby lib for use influxdb version 2 on Ruby language

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'latias-influxdb'
```

And then execute:

```bash
$ bundle
```

Or install it yourself as:

```bash
$ gem install latias-influxdb
```

Check version

```bash
 rails latias:influxdb:verion
```

## Configuration & Usage

### Configuration

First generating config file

```bash
 rails g latias:influxdb:install
```

```ruby
# config/initializers/latias_influxdb
Latias::Influxdb.configure do |config|
  # default
  # config.url = 'http://localhost:8086'
  # config.token = 'token'
  # config.bucket = 'bucket'
  # config.org = 'org'
  # config.use_ssl = false
  # config.verify_mode = OpenSSL::SSL::VERIFY_NONE
end
```

### Usage

You can use

<!--

  # config.url = 'http://188.166.252.165:8086'
  # config.token = 'YyD4UGu4_Xn0CIVsycFdjaQVd7m1g5wRp0z2BCfBSyNL6-GHqqyZRePGy46B2m8Zg6jgqHAN_J6jyhCmvGeQRA=='
  # config.bucket = 'MDBEnergy'
  # config.org = 'MDBEnergy'

-->

```ruby
  bucket = Latias::Influxdb::Bucket.new
  bucket.client_connection
  # or bucket = Latias::Influxdb::Bucket.new.client_connection
  bucket.range('start: -1m').filter('fn: (r) => r["_measurement"] == "cpu"')
  bucket.call
```

Or use with model

<!-- ```ruby
class MdbEnergyBucket < Latias::Influxdb::Bucket
  def initialize
    @url = 'http://188.166.252.165:8086'
    @token = 'YyD4UGu4_Xn0CIVsycFdjaQVd7m1g5wRp0z2BCfBSyNL6-GHqqyZRePGy46B2m8Zg6jgqHAN_J6jyhCmvGeQRA=='
    @bucket = 'MDBEnergy'
    @org = 'MDBEnergy'
    @use_ssl = false
    client_connection
  end
end

mdb_energy_bucket = MdbEnergyBucket.new
mdb_energy_bucket.range('start: -1m').filter('fn: (r) => r["_measurement"] == "cpu"')
mdb_energy_bucket.call
``` -->

```ruby
class MdbEnergyBucket < Latias::Influxdb::Bucket
  def initialize
    @url = 'http://localhost:8086'
    @token = 'your token'
    @bucket = 'MDBEnergy'
    @org = 'MDBEnergy'
    @use_ssl = false
    client_connection
  end
end

mdb_energy_bucket = MdbEnergyBucket.new
mdb_energy_bucket.range('start: -1m').filter('fn: (r) => r["_measurement"] == "cpu"')
mdb_energy_bucket.call
```

And you can add methods in model

```ruby

class MdbEnergyBucket < Latias::Influxdb::Bucket
  def initialize
    @url = 'http://localhost:8086'
    @token = 'your token'
    @bucket = 'MDBEnergy'
    @org = 'MDBEnergy'
    @use_ssl = false
    client_connection
  end

  def one_minute_before
    range('start: -1m')
  end

  def find_cpu
    filter('fn: (r) => r["_measurement"] == "cpu"')
  end

  def my_cpu_value
    one_minute_before.find_cpu.call
  end
end

mdb_energy_bucket = MdbEnergyBucket.new
mdb_energy_bucket.one_minute_before.find_cpu.call
# OR
mdb_energy_bucket.my_cpu_value
```

## Method

```ruby
def yield(query)
  merge_query('yield', query)
end

def range(query)
  merge_query('range', query)
end

def filter(query)
  merge_query('filter', query)
end

def duplicate(query)
  merge_query('duplicate', query)
end

def merge_query(key, query)
  raw_function "#{key}(#{query})"
end

def raw_function(function)
  raw_query "#{new_command} #{function}"
end

def raw_query(query)
  @query += query
  self
end

def client_reconnection
  client_connection
end

# And

def execute(query)
  @query = query
end

```

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Build and push GEM

```bash
gem build latias-influxdb.gemspec
gem push latias-influxdb-xx.xx.xx.gem
```
